@@ -95,13 +95,14 @@ class Api:
         res.raise_for_status()
         return res.json()['activities']
 
+    @cached('activity.{activity_id}', timedelta(hours=6))
     def get_activity(self, activity_id):
         res = self._api_call(f'api/activities/{activity_id}')
         res.raise_for_status()
         return res.json()
 
     def get_document(self, ref_id, preview=False):
-        res = self._api_call(f'https://courses.zju.edu.cn/api/uploads/reference/document/{ref_id}/url',
+        res = self._api_call(f'api/uploads/reference/document/{ref_id}/url',
                              params={'preview': str(preview).lower()})
         res.raise_for_status()
         url = res.json()['url']
